@echo off

REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM 
REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM 
REM
REM %%VER Batch File to put SMT drivers in AUTOEXEC.BAT & SYSTEM.INI (v1.2a)
REM
REM     This batch file updates the AUTOEXEC.BAT and SYSTEM.INI files 
REM     as required to run the SMT software. This batch file assumes 
REM     default installations for both LAN Manager and Windows.
REM     Specifically, the SMT drivers must be located in the
REM     C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK directory, and Windows must
REM     be installed in the C:\WINDOWS directory.
REM


REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM 
REM
REM     Modify the AUTOEXEC.BAT file. If the LANMAN section is not found
REM     then report an error and return.

REM
REM     Check for the existance of the AUTOEXEC.BAT file.
REM

IF EXIST c:\autoexec.bat GOTO FoundAutoexec

ECHO The "C:\AUTOEXEC.BAT" file is not present. The SMT drivers for this
ECHO system must be installed manually. Please refer to the NDIS.TXT file 
ECHO in the README directory for more information.
TYPE UTILITY\NDIS\BLANK.LIN
goto End

:FoundAutoexec

IF NOT EXIST C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK\SMT.EXE GOTO NoDrivers
IF EXIST C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK\RSMT.COM GOTO FoundDrivers

:NoDrivers

ECHO The SMT drivers (SMT.EXE and RSMT.COM) are not present in the LAN Manager
ECHO directory (C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK). If the drivers have not been
ECHO imported by the LAN Manager Setup program, do so now and then re-run this
ECHO program. If LAN Manager is not being used, or if it has not been installed
ECHO in the default location, you must update AUTOEXEC.BAT manually. Please 
ECHO refer to the NDIS.TXT file in the README directory for more information.
TYPE UTILITY\NDIS\BLANK.LIN
GOTO End

:FoundDrivers

ECHO Updating C:\AUTOEXEC.BAT

REM
REM     Make a working file and delete any current references to 
REM     the SMT files.
REM


COPY c:\autoexec.bat tmp.tmp > NUL:
IF ERRORLEVEL 1 GOTO DOSError
UTILITY\CSED /f tmp.tmp /d "*RSMT*"
UTILITY\CSED /f tmp.tmp /d "*SMT*"

REM
REM     Put in calls to the SMT drivers.
REM

UTILITY\CSED /f tmp.tmp /b "*=== LANMAN*" "C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK\RSMT"
IF ERRORLEVEL 1 GOTO DOSError
UTILITY\CSED /f tmp.tmp /b "*=== LANMAN*" "C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK\SMT"
IF ERRORLEVEL 1 GOTO DOSError

REM
REM     Move the files around so that the old AUTOEXEC.BAT file is named
REM     AUTOEXEC.OLD. 
REM

COPY c:\autoexec.bat c:\autoexec.old > NUL:
IF ERRORLEVEL 1 GOTO DOSError
COPY tmp.tmp c:\autoexec.bat > NUL:
IF ERRORLEVEL 1 GOTO DOSError
del tmp.tmp > NUL:

ECHO AUTOEXEC.BAT has been updated. An original copy has been named AUTOEXEC.OLD
TYPE UTILITY\NDIS\BLANK.LIN
GOTO CheckSystemINI

REM
REM     This section handles errors while updating AUTOEXEC.BAT
REM

:DOSError

del tmp.tmp > nul

ECHO *** Error:  AUTOEXEC.BAT could not be updated! ***
ECHO Make sure that you have access rights to the files
ECHO and that LAN Manager is properly installed.
TYPE UTILITY\NDIS\BLANK.LIN
GOTO End




REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM REM 
REM
REM     Modify, if requested, the SYSTEM.INI file in the Windows directory.
REM

:CheckSystemINI

REM
REM     Check the first parameter. If it's not present, don't update 
REM     the SYSTEM.INI file.
REM

IF (%1) == () GOTO End

REM
REM     Check for the existance of the SYSTEM.INI file, if specified.
REM

IF EXIST c:\windows\system.ini GOTO FoundSystemini

ECHO The "C:\WINDOWS\SYSTEM.INI" file is not present. The DOS16M.386 driver
ECHO for this system must be installed manually. Please refer to the NDIS.TXT
ECHO file in the README directory for more information.
TYPE UTILITY\NDIS\BLANK.LIN
GOTO End


:FoundSystemini


IF EXIST c:\lanman.dos\drivers\fddi\FDDILINK\dos16m.386 GOTO WinDriverFound


ECHO The SMT Windows VxD (DOS16M.386) is not present. SYSTEM.INI cannot be updated. 
ECHO DO NOT RUN WINDOWS UNTIL DOS16M.386 HAS BEEN PLACED INTO THE [386Enh] SECTION.
ECHO Refer to the NDIS.TXT file in the README directory for more information.
TYPE UTILITY\NDIS\BLANK.LIN
GOTO End

:WinDriverFound


REM
REM     Make a working file and delete any current references to 
REM     the SMT files.
REM

ECHO Updating C:\WINDOWS\SYSTEM.INI

COPY c:\windows\system.ini tmp.tmp > NUL:
IF ERRORLEVEL 1 GOTO WinError
UTILITY\CSED /f tmp.tmp /d "*DOS16M*"

REM
REM     Put in calls to the SMT drivers.
REM

UTILITY\CSED /f tmp.tmp /a "*[386Enh]*" "DEVICE=C:\LANMAN.DOS\DRIVERS\FDDI\FDDILINK\DOS16M.386"
UTILITY\CSED /f tmp.tmp /a "*[386Enh]*" "; DOS16M.386 added to support SMT.EXE and the Rational DOS extender."
IF ERRORLEVEL 1 GOTO WinError

REM
REM     Move the files around so that the old AUTOEXEC.BAT file is named
REM     AUTOEXEC.OLD. 
REM

COPY c:\windows\system.ini c:\windows\system.old > nul
IF ERRORLEVEL 1 GOTO WinError
COPY tmp.tmp c:\windows\system.ini > nul
IF ERRORLEVEL 1 GOTO WinError
del tmp.tmp > NUL:

ECHO SYSTEM.INI has been updated. An original copy has been named SYSTEM.OLD
TYPE UTILITY\NDIS\BLANK.LIN
GOTO End


:WinError
del tmp.tmp > nul

ECHO *** Error:  SYSTEM.INI could not be updated! ***
ECHO Make sure that you have access rights to the files.
TYPE UTILITY\NDIS\BLANK.LIN
GOTO End


REM
REM     Hold on the screen to let the user read it.
REM     Then return to the menuing system.

:End

ECHO Strike any key to return to the NDIS installation menu.
pause > nul:

